Changelog
=========

1.0.0
------------------
* **Dropped support to Python 2**
* Added CHANGELOG
* Removed deprecated testing functions
* Rearranged files to a better packaging organization
* Fixed setup.py requirements parsing
* Added GitHub Actions CI
* General improvements to PyPI setup.py, including long description


0.7.8
------------------

* Improved classes and functions descriptions

0.7.7
------------------

* Improved docs
* Small fixes

0.7.6
------------------

* Improvements for detecting and displaying classes and functions descriptions

0.7.5
------------------

* Moved the code to use 4 spaces and to be flake8 compliant

0.7.4
------------------

* Another small fix to handle setup package version dinamically

0.7.3
------------------

* Small fix to handle setup package version dinamically

0.7.2
------------------

* Added support to multiple versions of Python: 2.7, 3.3, 3.4, 3.5
* Added first documentation initiative with a Read the Docs page


0.5.3
------------------

* Added more detailed exceptions
* Detected when an unexpected exception raised during a test to consider as a failed test
* Make it possible to stub out a whole class and its properties and methods with mocks
* Added more comparators


0.5.2
------------------

* Provided logic for mocking classes that are iterable
* Tweaks, bugs fixes and improvements

0.5.1
------------------

* Added first README
* Added __str__ and __repr__ to Mox class
* Added a call checker for args and kwargs passed to functions
* Added a Not comparator
* Making it possible to mock container classes

0.5.0
------------------

* First release
